==> 6.3.1.tar.gz: botendo/src/main/kotlin/de/limited_dev/botendo/extensions/util/InfoExtension.kt <==
/*
 *     Botendo
 *     Copyright (C) 2023  limited_dev
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

package de.limited_dev.botendo.extensions.util

import com.kotlindiscord.kord.extensions.extensions.Extension
import com.kotlindiscord.kord.extensions.extensions.publicSlashCommand
import de.limited_dev.botendo.build.BuildConstants
import de.limited_dev.botendo.util.MessageUtil
import dev.kord.common.Color

class InfoExtension : Extension() {
    override val name = "info"
    override suspend fun setup() {
        publicSlashCommand {
            name = "info"
            description = "Show infos about the bot"
            this.action {
                MessageUtil.sendEmbedForPublicSlashCommand(
                    this, Color(0x52E01A), "Botendo",
                    "Botendo ***v." + BuildConstants.version + "***\n" +
                            "Kord-Extensions ***v." + BuildConstants.kordVersion + "***\n" +
                            "lavalink.kt ***v." + BuildConstants.lavaVersion + "***\n" +
                            "Coroutines ***v." + BuildConstants.coroutinesVersion + "***\n" +
                            "Ktor ***v." + BuildConstants.ktorVersion + "***\n" +
                            "Exposed ***v." + BuildConstants.exposedVersion + "***\n" +
                            "PostgreSQL ***v." + BuildConstants.postgresVersion + "***"
                )
            }
        }
    }
}

==> 6.3.2.tar.gz: botendo/src/main/kotlin/de/limited_dev/botendo/extensions/util/InfoExtension.kt <==
/*
 *     Botendo
 *     Copyright (C) 2023  limited_dev
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

package de.limited_dev.botendo.extensions.util

import com.kotlindiscord.kord.extensions.extensions.Extension
import com.kotlindiscord.kord.extensions.extensions.publicSlashCommand
import de.limited_dev.botendo.build.BuildConstants
import de.limited_dev.botendo.util.MessageUtil
import dev.kord.common.Color

class InfoExtension : Extension() {
    override val name = "info"
    override suspend fun setup() {
        publicSlashCommand {
            name = "info"
            description = "Show infos about the bot"
            this.action {
                MessageUtil.sendEmbedForPublicSlashCommand(
                    this, Color(0x52E01A), "Botendo",
                    "Botendo ***v." + BuildConstants.version + "***\n" +
                            "Kord-Extensions ***v." + BuildConstants.kordVersion + "***\n" +
                            "lavalink.kt ***v." + BuildConstants.lavaVersion + "***\n" +
                            "Coroutines ***v." + BuildConstants.coroutinesVersion + "***\n\n\n" +
                            "***Bot made by moonleay#7441***\n" +
                            "(c) 2023, licensed under GPL-3.0"
                )
            }
        }
    }
}
